@@ -50,6 +50,9 @@ class BaseScheduler(object):
             uuid_number: str,
             project_name: str,
             redis_job_store: RedisJobStore,
+            misfire_grace_time: int = 10,
+            coalesce: bool = True,
+            max_instances: int = 1,
 
     ) -> None:
         self.uuid_number = uuid_number
@@ -58,6 +61,9 @@ class BaseScheduler(object):
         self.scheduler = scheduler
         self.process_id_list = []
         self.redis_job_store = redis_job_store
+        self.misfire_grace_time = misfire_grace_time
+        self.coalesce = coalesce
+        self.max_instances = max_instances
 
     def scheduler_add_job(
             self,
@@ -83,9 +89,9 @@ class BaseScheduler(object):
             'kwargs': crawler_info,
             'id': job_id,
             'name': None,
-            'misfire_grace_time': undefined,
-            'coalesce': undefined,
-            'max_instances': undefined,
+            'misfire_grace_time': self.misfire_grace_time,
+            'coalesce': self.coalesce,
+            'max_instances': self.max_instances,
             'next_run_time': undefined
         }
         job_kwargs = dict((key, value) for key, value in six.iteritems(job_kwargs) if value is not undefined)
